==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/SeriesFocusHighlightingManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HighlightingManager } from "igniteui-react-core";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var SeriesFocusHighlightingManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesFocusHighlightingManager, _super);
    function SeriesFocusHighlightingManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesFocusHighlightingManager.prototype.isCrossContextHighlight = function (a) {
        var b = a;
        if (b.cm == 3 || b.cm == 4) {
            return true;
        }
        return false;
    };
    SeriesFocusHighlightingManager.prototype.isContextValid = function (a) {
        var b = a;
        return b != null && b.c9 != null;
    };
    SeriesFocusHighlightingManager.$t = markType(SeriesFocusHighlightingManager, 'SeriesFocusHighlightingManager', HighlightingManager.$);
    return SeriesFocusHighlightingManager;
}(HighlightingManager));
export { SeriesFocusHighlightingManager };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/SeriesFocusHighlightingManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HighlightingManager } from "igniteui-react-core";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var SeriesFocusHighlightingManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesFocusHighlightingManager, _super);
    function SeriesFocusHighlightingManager() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesFocusHighlightingManager.prototype.isCrossContextHighlight = function (a) {
        var b = a;
        if (b.co == 3 || b.co == 4) {
            return true;
        }
        return false;
    };
    SeriesFocusHighlightingManager.prototype.isContextValid = function (a) {
        var b = a;
        return b != null && b.db != null;
    };
    SeriesFocusHighlightingManager.$t = markType(SeriesFocusHighlightingManager, 'SeriesFocusHighlightingManager', HighlightingManager.$);
    return SeriesFocusHighlightingManager;
}(HighlightingManager));
export { SeriesFocusHighlightingManager };
